powered by
Launch an example shiny app using shinyauthr authentication modules. Use user1 pass1 or user2 pass2 to login.
runExample(example = c("basic", "shinydashboard", "navbarPage"))
The app to launch. Options are "basic", "shinydashboard" or "navbarPage"
No return value, a shiny app is launched.
# NOT RUN { ## Only run this example in interactive R sessions if (interactive()) { runExample("basic") runExample("shinydashboard") runExample("navbarPage") } # }
Run the code above in your browser using DataLab