These functions silently reject all cookies during login and ignore requests to save session ids to a database. Use these if you don't want to allow automatic login with cookies. These are default values for `callModule(shinyauthr::login, ...)`. Replace them with your own functions which get and set the user and session ids in a database.
default_cookie_getter(user_string, session_string)default_cookie_setter(user, session)
character string representing the user id
character string representing the session id
`default_cookie_setter` returns a data.frame with zero rows and two columns: `user` and `session`